==> cydex_3.2-buildbeta1_installer_oem-cicc.tar.gz: cydex_3.2-buildbeta1_installer_oem-cicc/install_zone.sh <==
#/bin/bash

echo -e "\n\n\n\n\n
 ██████╗██╗   ██╗██████╗ ███████╗██╗  ██╗
██╔════╝╚██╗ ██╔╝██╔══██╗██╔════╝╚██╗██╔╝
██║      ╚████╔╝ ██║  ██║█████╗   ╚███╔╝
██║       ╚██╔╝  ██║  ██║██╔══╝   ██╔██╗
╚██████╗   ██║   ██████╔╝███████╗██╔╝ ██╗
 ╚═════╝   ╚═╝   ╚═════╝ ╚══════╝╚═╝  ╚═╝   version 3.2\n\n\n"

echo "This script will install or upgrade Cydex3-zone and Cydex3-node services on this host !!!"
echo -e "Continue? (Y/n) \c "
read answer
if !([ $answer == "Y" ] || [ $answer == "y" ]); then
    echo "Abort!"
    exit 0
fi

echo -e "\n"
echo "[Cydex] Stop Zone ... "
systemctl stop cydex3-zone > /dev/null 2>&1

echo -e "\n"
echo "[Cydex] Install system components ... "
yum update -y
yum install -y epel-release

if rpm -q nginx >/dev/null 2>&1; then
    echo "This script will Reinstall Nginx services on this host !!!"
    echo -e "Continue Reinstalling Nginx? (Y/n) \c "
    read answer
    if ([ $answer == "Y" ] || [ $answer == "y" ]); then
        systemctl stop nginx
        yum remove -y nginx
        yum install -y nginx
    fi
else
    yum install -y nginx
fi

yum install -y redis
yum install -y iptables-services
sh scripts/install_mysql.sh

echo -e "\n"
echo "[Cydex] Install Cydex components ... "
pkgs=`ls cydex_rpms/*zone*.rpm`
for pkg in $pkgs
do
	rpm -Uvh --force $pkg
done
pkgs=`ls cydex_rpms/*node*.rpm`
for pkg in $pkgs
do
	rpm -Uvh $pkg
done

echo -e "\n"
echo "[Cydex] Config system and Cydex ... "
sh scripts/disable_selinux.sh
sh scripts/config_zone_nginx.sh
sh scripts/config_redis.sh
sh scripts/config_zone_mysql.sh
sh scripts/sysctl_net.sh
sh scripts/config_rsyslog.sh
sh scripts/config_iptables.sh
sh scripts/config_zone_center.sh
sh scripts/config_zone_key.sh

echo -e "\n"
echo "[Cydex] Start Zone ... "
systemctl stop cydex3-zone > /dev/null 2>&1

echo -e "\n"
echo "***********************************"
echo "* Cydex zone is installed successfully. "
echo "* DON'T FORGET to config 'cydex3-node' and run it !!!" 
echo "***********************************"
echo -e "\n"
echo -e "\n"

==> cydex_3.3.2-buildbeta1_installer_oem-cicc.tar.gz: cydex_3.3.2-buildbeta1_installer_oem-cicc/install_zone.sh <==
#/bin/bash

echo -e "\n\n\n\n\n
 ██████╗██╗   ██╗██████╗ ███████╗██╗  ██╗
██╔════╝╚██╗ ██╔╝██╔══██╗██╔════╝╚██╗██╔╝
██║      ╚████╔╝ ██║  ██║█████╗   ╚███╔╝
██║       ╚██╔╝  ██║  ██║██╔══╝   ██╔██╗
╚██████╗   ██║   ██████╔╝███████╗██╔╝ ██╗
 ╚═════╝   ╚═╝   ╚═════╝ ╚══════╝╚═╝  ╚═╝   version 3.3.2\n\n\n"

echo "This script will install or upgrade Cydex3-zone and Cydex3-node services on this host !!!"
echo -e "Continue? (Y/n) \c "
read answer
if !([ $answer == "Y" ] || [ $answer == "y" ]); then
    echo "Abort!"
    exit 0
fi

echo -e "\n"
echo "[Cydex] Stop Zone ... "
systemctl stop cydex3-zone > /dev/null 2>&1

echo -e "\n"
echo "[Cydex] Install system components ... "
yum update -y
yum install -y epel-release

if rpm -q nginx >/dev/null 2>&1; then
    echo "This script will Reinstall Nginx services on this host !!!"
    echo -e "Continue Reinstalling Nginx? (Y/n) \c "
    read answer
    if ([ $answer == "Y" ] || [ $answer == "y" ]); then
        systemctl stop nginx
        yum remove -y nginx
        yum install -y nginx
    fi
else
    yum install -y nginx
fi

yum install -y redis
yum install -y iptables-services
sh scripts/install_mysql.sh

echo -e "\n"
echo "[Cydex] Install Cydex components ... "
pkgs=`ls cydex_rpms/*zone*.rpm`
for pkg in $pkgs
do
	rpm -Uvh --force $pkg
done
pkgs=`ls cydex_rpms/*node*.rpm`
for pkg in $pkgs
do
	rpm -Uvh $pkg
done

echo -e "\n"
echo "[Cydex] Config system and Cydex ... "
sh scripts/disable_selinux.sh
sh scripts/config_zone_nginx.sh
sh scripts/config_redis.sh
sh scripts/config_zone_mysql.sh
sh scripts/sysctl_net.sh
sh scripts/config_rsyslog.sh
sh scripts/config_iptables.sh
sh scripts/config_zone_center.sh
sh scripts/config_zone_key.sh

echo -e "\n"
echo "[Cydex] Start Zone ... "
systemctl stop cydex3-zone > /dev/null 2>&1

echo -e "\n"
echo "***********************************"
echo "* Cydex zone is installed successfully. "
echo "* DON'T FORGET to config 'cydex3-node' and run it !!!" 
echo "***********************************"
echo -e "\n"
echo -e "\n"
